/*
 * $Id: GUI.java,v 1.3 2002-09-01 15:05:12-07 ball Exp $
 *
 * Copyright 2002 Allen D. Ball.  All rights reserved.
 */
package gui;

import java.awt.*;
import javax.swing.*;
import javax.swing.table.*;
import player.*;
import world.*;

/**
 * This class implements a GUI for monitoring the game world.
 *
 * @author <a href="mailto:ball@iprotium.com">Allen D. Ball</a>
 * @version $Revision: 1.3 $
 */
public class GUI extends JFrame {
    private static int jspHorizontalPolicy =
        JScrollPane.HORIZONTAL_SCROLLBAR_ALWAYS;
    private static int jspVerticalPolicy =
        JScrollPane.VERTICAL_SCROLLBAR_ALWAYS;

    private World world = null;
    private Player player = null;
    private JTable worldTable = null;
    private JTable robotTable = null;
    /* private JTable robotSackTable = null; */
    private TTY tty = new TTY(12, 80);

    /**
     * Creates the GUI to monitor the world.
     *
     * @param   title           The title to use for the JFrame.
     * @param   world           The world to monitor.
     *
     * @see JFrame
     */
    public GUI(String title, World world, Player player) {
        super(title);

        this.world = world;

        getContentPane().setLayout(new BorderLayout());

        worldTable = new JTable();
        worldTable.setAutoResizeMode(JTable.AUTO_RESIZE_OFF);
        JScrollPane worldTablePane = new JScrollPane(worldTable);
        worldTablePane.setHorizontalScrollBarPolicy(jspHorizontalPolicy);
        worldTablePane.setVerticalScrollBarPolicy(jspVerticalPolicy);

        robotTable = new JTable();
        robotTable.setAutoResizeMode(JTable.AUTO_RESIZE_OFF);
        JScrollPane robotTablePane = new JScrollPane(robotTable);
        robotTablePane.setHorizontalScrollBarPolicy(jspHorizontalPolicy);
        robotTablePane.setVerticalScrollBarPolicy(jspVerticalPolicy);
/*
        robotSackTable = new JTable();
        robotSackTable.setAutoResizeMode(JTable.AUTO_RESIZE_OFF);
        JScrollPane robotSackTablePane = new JScrollPane(robotSackTable);
        robotSackTablePane.setHorizontalScrollBarPolicy(jspHorizontalPolicy);
        robotSackTablePane.setVerticalScrollBarPolicy(jspVerticalPolicy);
*/
        JScrollPane ttyPane = new JScrollPane(tty);
        ttyPane.setHorizontalScrollBarPolicy(jspHorizontalPolicy);
        ttyPane.setVerticalScrollBarPolicy(jspVerticalPolicy);

        getContentPane().add(worldTablePane, BorderLayout.NORTH);
        getContentPane().add(robotTablePane, BorderLayout.WEST);
        /* getContentPane().add(robotSackTablePane, BorderLayout.CENTER); */
        getContentPane().add(ttyPane, BorderLayout.EAST);
    }

    private GUI() { }

    /**
     * Method to get GUI's TTY..
     *
     * @return                  The GUI's TTY.
     */
    public TTY getTTY() { return tty; }

    /**
     * Method to notify GUI game turn is complete.
     */
    public void notifyTurn() {
        if (worldTable.getModel() != world.getTableModel()) {
            worldTable.setModel(world.getTableModel());
            Util.setJTablePreferredWidths(worldTable);
        }

        ((AbstractTableModel) world.getTableModel()).fireTableDataChanged();

        if (robotTable.getModel() != world.getRobotMap().getTableModel()) {
            robotTable.setModel(world.getRobotMap().getTableModel());
            Util.setJTablePreferredWidths(robotTable);
        }

        ((AbstractTableModel) world.getRobotMap().getTableModel())
            .fireTableDataChanged();

        Thread.currentThread().yield();
    }
}
/*
 * $Log: GUI.java,v $
 * Revision 1.3  2002-09-01 15:05:12-07  ball
 * Moved package because it should be able to display both world and player
 * stuff.
 *
 * Revision 1.2  2002-09-01 08:50:25-07  ball
 * Limit size of TTY buffer.
 * Set table preferred widths when assigning a new model.
 *
 * Revision 1.1  2002-08-31 17:55:45-07  ball
 * Initial revision
 *
 */
