/*
 * $Id: Strategy.java,v 1.2 2002-09-01 15:08:40-07 ball Exp $
 *
 * Copyright 2002 Allen D. Ball.  All rights reserved.
 */
package player;

/**
 * Abstract Class that implements a player strategy for the ICFP-2002
 * programming contest.
 *
 * @author <a href="mailto:ball@iprotium.com">Allen D. Ball</a>
 * @version $Revision: 1.2 $
 */
public abstract class Strategy {

    /**
     * The player who owns the strategy.
     */
    protected Player player = null;

    /**
     * Creates a player strategy.
     */
    protected Strategy() { }

    /**
     * Method to get the strategy's player.
     *
     * @return                  The player this strategy is operating for.
     */
    public Player getPlayer() { return player; }

    /**
     * Method to initialize the strategy.  Subclasses that override
     * this method should chain a call the superclass's method.
     *
     * @param   player          The player on whose behalf this
     *                          strategy will operate.
     */
    public void initialize(Player player) { this.player = player; }

    /**
     * Method to calculate the player's robot next command.
     *
     * @return                  The next command to send to the player's
     *                          robot.
     */
    public abstract Command nextCommand();
}
/*
 * $Log: Strategy.java,v $
 * Revision 1.2  2002-09-01 15:08:40-07  ball
 * Made setting of command arguments consistent for all subclasses
 * of Command.
 * Added an initialization method to Strategy classes.
 * Player will submit a no-op move if the Strategy implementation
 * does not return a command.
 *
 * Revision 1.1  2002-08-31 17:46:24-07  ball
 * Initial revision
 *
 */
