/*
 * $Id: IdMapTableModel.java,v 1.2 2002-09-01 15:10:58-07 ball Exp $
 *
 * Copyright 2002 Allen D. Ball.  All rights reserved.
 */
package world;

import java.awt.*;
import javax.swing.*;
import javax.swing.table.*;

/**
 * This class implements a TableModel for {@link IdMap}s.
 *
 * @author <a href="mailto:ball@iprotium.com">Allen D. Ball</a>
 * @version $Revision: 1.2 $
 */
public class IdMapTableModel extends AbstractTableModel {
    private static String[] columnNames = { "ID", "Object" };

    private IdMap idMap = null;

    public IdMapTableModel(IdMap idMap) {
        super();
        this.idMap = idMap;
    }

    public int getColumnCount() { return columnNames.length; }

    public String getColumnName(int column) { return columnNames[column]; }

    public int getRowCount() {
        int count = 0;

        synchronized(idMap) {
            count = idMap.size();
        }

        return count;
    }

    public Object getValueAt(int row, int column) {
        Object key = null;
        Object value = null;

        synchronized (idMap) {
            if (0 <= row && row < getRowCount()) {
                key = idMap.keySet().toArray()[row];
            }
        }

        switch (column) {
        case 0:
            value = key.toString();
            break;

        case 1:
            synchronized (idMap) {
                value = idMap.get(key);
            }
            break;

        default:
            break;
        }

        return value;
    }
}
/*
 * $Log: IdMapTableModel.java,v $
 * Revision 1.2  2002-09-01 15:10:58-07  ball
 * Tiles and Robots both use Sacks to hold packages.
 * Added standard Directions.  Added methods to Tile and Position
 * to take advantage of Directions.
 * GUI is no longer World-specific.
 *
 * Revision 1.1  2002-08-31 17:55:45-07  ball
 * Initial revision
 *
 */
