/*
 * $Id: Path.java,v 1.1 2002-09-02 03:22:25-07 ball Exp $
 *
 * Copyright 2002 Allen D. Ball.  All rights reserved.
 */
package world;

import java.util.*;

/**
 * Class to record paths through tiles.
 *
 * @author <a href="mailto:ball@iprotium.com">Allen D. Ball</a>
 * @version $Revision: 1.1 $
 */
public class Path extends PathKey {
    private final Tile[] tiles;
    private final int[] steps;

    /**
     * Creates a path.
     */
    protected Path(Tile start, Tile end, Tile[] tiles, int[] steps) {
        super(start, end);
        this.tiles = tiles;
        this.steps = steps;
    }

    /**
     * Creates a path for a start and an end which cannot be connected.
     */
    protected Path(Tile start, Tile end) { this(start, end, null, null) ; }

    public Tile[] getTiles() { return tiles; }

    public int[] getSteps() { return steps; }

    public boolean isConnected() { return steps != null; }

    public int getDistance() {
        int distance = 0;

        if (isConnected()) {
            distance = steps.length;
        } else {
            distance = Integer.MAX_VALUE;
        }

        return distance;
    }
}
/*
 * $Log: Path.java,v $
 * Revision 1.1  2002-09-02 03:22:25-07  ball
 * Initial revision
 *
 */
