/*
 * $Id: Pkg.java,v 1.2 2002-09-01 23:38:55-07 ball Exp $
 *
 * Copyright 2002 Allen D. Ball.  All rights reserved.
 */
package world;

/**
 * Class that implements packages for the ICFP-2002 programming contest
 * entry.
 *
 * @author <a href="mailto:ball@iprotium.com">Allen D. Ball</a>
 * @version $Revision: 1.2 $
 */
public class Pkg implements ID {
    private int id = 0;
    private int weight = 0;
    private Tile destination = null;

    /**
     * Creates a package.
     *
     * @param   id              The package ID.
     * @param   weight          The package's weight.
     * @param   destination     The package's destination position.
     */
    public Pkg(int id, int weight, Tile destination) {
        this.id = id;
        this.weight = weight;
        this.destination = destination;
    }

    /**
     * Method to get the package ID.
     *
     * @return                  The package ID.
     */
    public int getId() { return id; }

    /**
     * Method to get the package's weight.
     *
     * @return                  The package's weight.
     */
    public int getWeight() { return weight; }

    /**
     * Method to get the package's destination position.
     *
     * @return                  The package's destination position.
     */
    public Tile getDestination() { return destination; }

    /**
     * Compares this object with the specified object for order.
     * Returns a negative integer, zero, or a positive integer as this
     * object is less than, equal to, or greater than the specified
     * object.
     *
     * @param   object          The object to be compared.
     *
     * @see java.lang.Comparable
     */
    public int compareTo(Object object) {
        return getId() - ((Robot) object).getId();
    }
}
/*
 * $Log: Pkg.java,v $
 * Revision 1.2  2002-09-01 23:38:55-07  ball
 * Combined Position class with Tile class.  Removed Position class.
 *
 * Revision 1.1  2002-08-31 17:52:00-07  ball
 * Initial revision
 *
 */
