/*
 * $Id: WaterTile.java,v 1.3 2002-09-01 22:08:34-07 ball Exp $
 *
 * Copyright 2002 Allen D. Ball.  All rights reserved.
 */
package world;

/**
 * Class that implements water tiles for the ICFP-2002 programming
 * contest entry.
 *
 * @author <a href="mailto:ball@iprotium.com">Allen D. Ball</a>
 * @version $Revision: 1.3 $
 */
public class WaterTile extends Tile {

    /**
     * Creates a water tile.
     *
     * @param   board           The playing board.
     * @param   row             The row position of the tile.
     * @param   column          The column position of the tile.
     *
     * @see Position
     */
    public WaterTile(Board board, int row, int column) {
        super(board, row, column);
    }

    public final boolean isPassable () { return false; }

    public final boolean isLethal() { return true; }
}
/*
 * $Log: WaterTile.java,v $
 * Revision 1.3  2002-09-01 22:08:34-07  ball
 * Removed extra GUI support from IdMap and subclasses -- The GUI used in
 * development will be updated at the end of every turn.
 * The Position class implements Comparable.  Also added a toString()
 * method suitable for displaying the coordinates of the position.
 * Added a method to the Tile class for calculating the path between tiles.
 * Marked a water tile as "impassable."
 *
 * Revision 1.2  2002-09-01 08:47:52-07  ball
 * Added position information to tiles.
 * Moved most diagnostic GUI code to World class.
 * Track player robot's actual and opponent robot's observed scores and
 * loads.  Track opponent robot's observed capacity.  Added methods to
 * manage, drop, and pick packages.
 * Add load and position columns to robot table.
 * Track game turn number.
 * Display robots on the world map.
 *
 * Revision 1.1  2002-08-31 17:52:00-07  ball
 * Initial revision
 *
 */
